@@ -140,9 +140,10 @@ class MixPage(Null, SessionPage, DriverPage):
         elif self._mode == 'd':
             return super(SessionPage, self).title
 
-    def set_cookies(self, cookies: Union[RequestsCookieJar, list, tuple, str, dict]) -> None:
+    def set_cookies(self, cookies: Union[RequestsCookieJar, list, tuple, str, dict], refresh: bool = True) -> None:
         """设置cookies                                                          \n
         :param cookies: cookies信息，可为CookieJar, list, tuple, str, dict
+        :param refresh: 设置cookies后是否刷新页面
         :return: None
         """
         if self._mode == 's':
@@ -150,6 +151,9 @@ class MixPage(Null, SessionPage, DriverPage):
         elif self._mode == 'd':
             self.drission.set_cookies(cookies, set_driver=True)
 
+            if refresh:
+                self.refresh()
+
     def get_cookies(self, as_dict: bool = False, all_domains: bool = False) -> Union[dict, list]:
         """返回cookies                               \n
         :param as_dict: 是否以字典方式返回
@@ -336,8 +340,8 @@ class MixPage(Null, SessionPage, DriverPage):
     def ele(self,
             loc_or_ele: Union[Tuple[str, str], str, DriverElement, SessionElement, WebElement],
             mode: str = None,
-            timeout: float = None) -> Union[
-        DriverElement, SessionElement, str, List[SessionElement], List[DriverElement]]:
+            timeout: float = None) \
+            -> Union[DriverElement, SessionElement, str, List[SessionElement], List[DriverElement]]:
         """返回页面中符合条件的元素、属性或节点文本，默认返回第一个                                            \n
         示例：                                                                                           \n
         - 接收到元素对象时：                                                                              \n
